@@ -7,12 +7,6 @@ MIME::Parser::Results - results of the last entity parsed
 
 =head1 SYNOPSIS
 
-Before reading further, you should see L<MIME::Parser> to make sure that 
-you understand where this module fits into the grand scheme of things.
-Go on, do it now.  I'll wait.
-
-Ready?  Ok...
-
    ### Do parse, get results:
    my $entity = eval { $parser->parse(\*STDIN); };
    my $results  = $parser->results;
@@ -28,11 +22,6 @@ Ready?  Ok...
    $top_head  = $results->top_head;
 
 
-=head1 DESCRIPTION
-
-Results from the last MIME::Parser parse.
-
-
 =head1 PUBLIC INTERFACE
 
 =over 4
@@ -138,34 +127,19 @@ sub top_head {
 sub msg {
     my $self = shift;
     my $type = shift;
-    my @args = map { defined($_) ? $_ : '<<undef>>' } @_;
-
-    push @{$self->{MPI_Msgs}}, ($type.": ".join('', @args)."\n");
+    push @{$self->{MPI_Msgs}}, ($type.": ".join('', @_)."\n");
 }
 
 #------------------------------
 #
 # level [+1|-1]
 #
-# Return current parsing level.
-#
 sub level {
     my ($self, $lvl) = @_;
     $self->{MPI_Level} += $lvl if @_ > 1;
     $self->{MPI_Level};
 }
 
-#------------------------------
-#
-# indent
-#
-# Return indent for current parsing level.
-#
-sub indent {
-    my ($self) = @_;
-    '   ' x $self->{MPI_Level};
-}
-
 =back
 
 =cut
@@ -184,7 +158,7 @@ it and/or modify it under the same terms as Perl itself.
 
 =head1 VERSION
 
-$Revision$
+$Revision: 5.206 $
 
 
 
